********
Citation
********

If you use CAMELS data you may considering citing the CAMELS `presentation <https://arxiv.org/abs/2010.00619>`_ and `data release <https://arxiv.org/abs/2201.01300>`_ papers:


::

   @ARTICLE{camels_presentation,
   author = {{Villaescusa-Navarro}, Francisco and {Angl{\'e}s-Alc{\'a}zar}, Daniel and {Genel}, Shy and {Spergel}, David N. and {Somerville}, Rachel S. and {Dave}, Romeel and {Pillepich}, Annalisa and {Hernquist}, Lars and {Nelson}, Dylan and {Torrey}, Paul and {Narayanan}, Desika and {Li}, Yin and {Philcox}, Oliver and {La Torre}, Valentina and {Maria Delgado}, Ana and {Ho}, Shirley and {Hassan}, Sultan and {Burkhart}, Blakesley and {Wadekar}, Digvijay and {Battaglia}, Nicholas and {Contardo}, Gabriella and {Bryan}, Greg L.},
   title = "{The CAMELS Project: Cosmology and Astrophysics with Machine-learning Simulations}",
   journal = {\apj},
   keywords = {Cosmology, Cosmological parameters from large-scale structure, Galaxy formation, Astrostatistics, 343, 340, 595, 1882, Astrophysics - Cosmology and Nongalactic Astrophysics, Astrophysics - Astrophysics of Galaxies, Astrophysics - Instrumentation and Methods for Astrophysics},
   year = 2021,
   month = jul,
   volume = {915},
   number = {1},
   eid = {71},
   pages = {71},
   doi = {10.3847/1538-4357/abf7ba},
   archivePrefix = {arXiv},
   eprint = {2010.00619},
   primaryClass = {astro-ph.CO},
   adsurl = {https://ui.adsabs.harvard.edu/abs/2021ApJ...915...71V},
   adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }


   @ARTICLE{camels_data_release,
   author = {{Villaescusa-Navarro}, Francisco and {Genel}, Shy and {Angl{\'e}s-Alc{\'a}zar}, Daniel and {Perez}, Lucia A. and {Villanueva-Domingo}, Pablo and {Wadekar}, Digvijay and {Shao}, Helen and {Mohammad}, Faizan G. and {Hassan}, Sultan and {Moser}, Emily and {Lau}, Erwin T. and {Machado Poletti Valle}, Luis Fernando and {Nicola}, Andrina and {Thiele}, Leander and {Jo}, Yongseok and {Philcox}, Oliver H.~E. and {Oppenheimer}, Benjamin D. and {Tillman}, Megan and {Hahn}, ChangHoon and {Kaushal}, Neerav and {Pisani}, Alice and {Gebhardt}, Matthew and {Delgado}, Ana Maria and {Caliendo}, Joyce and {Kreisch}, Christina and {Wong}, Kaze W.~K. and {Coulton}, William R. and {Eickenberg}, Michael and {Parimbelli}, Gabriele and {Ni}, Yueying and {Steinwandel}, Ulrich P. and {La Torre}, Valentina and {Dave}, Romeel and {Battaglia}, Nicholas and {Nagai}, Daisuke and {Spergel}, David N. and {Hernquist}, Lars and {Burkhart}, Blakesley and {Narayanan}, Desika and {Wandelt}, Benjamin and {Somerville}, Rachel S. and {Bryan}, Greg L. and {Viel}, Matteo and {Li}, Yin and {Irsic}, Vid and {Kraljic}, Katarina and {Vogelsberger}, Mark},
   title = "{The CAMELS project: public data release}",
   journal = {arXiv e-prints},
   keywords = {Astrophysics - Cosmology and Nongalactic Astrophysics, Astrophysics - Astrophysics of Galaxies, Astrophysics - Instrumentation and Methods for Astrophysics, Computer Science - Artificial Intelligence, Computer Science - Machine Learning},
   year = 2022,
   month = jan,
   eid = {arXiv:2201.01300},
   pages = {arXiv:2201.01300},
   archivePrefix = {arXiv},
   eprint = {2201.01300},
   primaryClass = {astro-ph.CO},
   adsurl = {https://ui.adsabs.harvard.edu/abs/2022arXiv220101300V},
   adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }
